package pl.elzab.virtualcomsample;

import java.util.List;
import android.app.Activity;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

import pl.elzab.virtualcomsample.dataobject.ListItemDataModel;
import pl.elzab.virtualcomsample.dataobject.StatusInfo;

/**
 * class used to access particular item of list on screen
 * @author ElzabSoft
 * @version 1.01
 */
public class MyArrayAdapter extends ArrayAdapter<ListItemDataModel> {
    /** item list */
    private final List<ListItemDataModel> mList;
    /** application context */
    private final Activity mContext;

    /** basic constructor
     * @param context application context
     * @param list instance of item list
     */
    public MyArrayAdapter(Activity context, List<ListItemDataModel> list) {
        super(context, R.layout.list_fields, list);
        mContext = context;
        mList = list;
    }

    /**
     * object that holds item's view
     */
    static class ViewHolder {
        protected TextView text;
        protected StatusInfo statusInfo;
    }

    /**
     * gets item based on item's list position
     * @param position item's list position
     * @return item
     */
    @Override
    public long getItemId(int position) {
        return mList.get(position).getId();
    }

    /**
     * gets view of list item based on item's list position
     * @param position item's list position
     * @param convertView view to fill
     * @param parent parent view
     * @return item's view
     */
    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View view = null;
        if (convertView == null) {
            LayoutInflater inflator = mContext.getLayoutInflater();
            view = inflator.inflate(R.layout.list_fields, null);
            final ViewHolder viewHolder = new ViewHolder();
            viewHolder.text = (TextView) view.findViewById(R.id.column1);
            view.setTag(viewHolder);
        } else
            view = convertView;
        ViewHolder holder = (ViewHolder) view.getTag();
        holder.text.setText(mList.get(position).getStatusInfo().GetText());
        holder.statusInfo = (mList.get(position).getStatusInfo());
        StatusInfo.MessageStatus ms = mList.get(position).getStatusInfo().GetStatus();
        if(ms == StatusInfo.MessageStatus.OK)
            holder.text.setTextColor(Color.GREEN);
        else if( ms == StatusInfo.MessageStatus.WARNING)
            holder.text.setTextColor(Color.YELLOW);
        else
            holder.text.setTextColor(Color.RED);
        return view;
    }
}
