package pl.elzab.virtualcomsample;

import android.content.Context;
import android.content.Intent;
import android.os.Parcelable;
import android.support.v4.content.LocalBroadcastManager;

/**
 * Helper class that provides useful methods.
 * @author ElzabSoft
 * @version 1.01
 */
public class Util {
    /**
     * concatenates multiple byte arrays
     * @param arrays multiple byte arrays
     * @return single byte array
     */
    public static byte[] ConcatenateByteArrays(byte[]... arrays) {
        int resultArrayLength = 0;
        for(byte[] array : arrays)
            resultArrayLength += array.length;
        byte[] resultArray = new byte[resultArrayLength];
        int index = 0;
        for(byte[] array : arrays)
            for(byte element : array)
                resultArray[index++] = element;
        return resultArray;
    }

    /**
     * converts string to byte array
     * @param text text as string
     * @return text as byte array
     */
    public static byte[] StringToByteArray(String text) {
        byte[] result = new byte[text.length()];
        for(int i=0; i<text.length(); i++)
            result[i] = (byte)text.charAt(i);
        return result;
    }

    /**
     * locally broadcasts parcelable object
     * @param parcelable parcelable object
     * @param intentFilter intent filter
     * @param extraName extra's name
     */
    public static void sendParcelable(Context context, Parcelable parcelable, String intentFilter, String extraName) {
        Intent intent = new Intent(intentFilter);
        intent.putExtra(extraName, parcelable);
        LocalBroadcastManager.getInstance(context).sendBroadcast(intent);
    }

    /**
     * locally broadcasts text string
     * @param value text value
     * @param intentFilter intent filter
     * @param extraName extra's name
     */
    public static void sendString(Context context, String value, String intentFilter, String extraName) {
        Intent intent = new Intent(intentFilter);
        intent.putExtra(extraName, value);
        LocalBroadcastManager.getInstance(context).sendBroadcast(intent);
    }
}
