package pl.elzab.virtualcomsample.activity;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.support.v4.content.LocalBroadcastManager;
import android.util.Log;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import java.util.ArrayList;
import java.util.List;
import pl.elzab.virtualcomsample.R;
import pl.elzab.virtualcomsample.dataobject.ListItemDataModel;
import pl.elzab.virtualcomsample.dataobject.Measurement;
import pl.elzab.virtualcomsample.dataobject.StatusInfo;
import pl.elzab.virtualcomsample.dataobject.StxErrorMessage;
import pl.elzab.virtualcomsample.USBConnection;
import pl.elzab.virtualcomsample.Communication;
import pl.elzab.virtualcomsample.MyArrayAdapter;

/**
 * Base activity for Prima2 activity and Zeteta/D10 activity.
 * @author ElzabSoft
 * @version 1.01
 */
public class UsbSerialActivity extends Activity {
    /** tag for logging */
    public static final String TAG = "ElzabUSB";
    /** broadcast receiver */
    protected BroadcastReceiver mMessageReceiver;
    /** list array adapter */
    protected ArrayAdapter mAdapter;
    /** list view */
    protected ListView mList;
    /* list of messages */
    protected List<ListItemDataModel> mDataList;
    /** communication object */
    protected Communication mCommunication;
    /** output field for status messages */
    protected TextView mDeviceOutputText;

    protected synchronized void ShowInfoOnScreen(StatusInfo statusInfo) {
        int dataListLength = mDataList.size();
        if( dataListLength > 0 && mDataList.get(dataListLength - 1).getStatusInfo().GetText().equals(statusInfo.GetText())) // don't reply last information
            return;
        ListItemDataModel mod = new ListItemDataModel(1, statusInfo);
        mDataList.add(mod);
        mAdapter.notifyDataSetChanged();
    }

    public void showListOnScreen(){
        mDataList = new ArrayList<ListItemDataModel>();
        mAdapter = new MyArrayAdapter(this, mDataList);
        mAdapter.notifyDataSetChanged();
        mList = (ListView)findViewById(R.id.messagesList);
        mList.setAdapter(mAdapter);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        mMessageReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                try {
                    StxErrorMessage stxErrorMessage = intent.getParcelableExtra("stx_error_message");
                    if( stxErrorMessage != null) {
                        ShowInfoOnScreen(new StatusInfo(stxErrorMessage.toString(), StatusInfo.MessageStatus.WARNING));
                        return;
                    }
                    String stxUniqueNumber = intent.getStringExtra("stx_unique_number");
                    if(stxUniqueNumber != null) {
                        mDeviceOutputText.setText(stxUniqueNumber);
                        return;
                    }
                    StatusInfo statusInfo = intent.getParcelableExtra("status_info");
                    if(statusInfo != null) {
                        ShowInfoOnScreen(statusInfo);
                        return;
                    }
                    Measurement measurement = intent.getParcelableExtra("weight_measurement");
                    if(measurement != null) {
                        mDeviceOutputText.setText(measurement.toString());
                        return;
                    }
                } catch (Exception e) {
                    Log.d(TAG, e.getMessage());
                }
            }
        };
    }

    @Override
    public void onStart(){
        super.onStart();
        LocalBroadcastManager.getInstance(this).registerReceiver(mMessageReceiver, new IntentFilter("message-for-activity"));
        if(mCommunication != null)
            mCommunication.restartListener(USBConnection.getConnection(this));
    }

    @Override
    protected void onStop() {
        super.onStop();
        LocalBroadcastManager.getInstance(this).unregisterReceiver(mMessageReceiver);
        USBConnection.closeConnection(getApplicationContext());
        if(mCommunication != null)
            mCommunication.stopListener();
    }
}
