package pl.elzab.virtualcomsample.dataobject;

import android.os.Parcel;
import android.os.Parcelable;

import pl.elzab.virtualcomsample.dataobject.StxErrorMessage;

/**
 * Simple object to represent information about dialog status
 * @author ElzabSoft
 * @version 1.01
 */
public class StatusInfo implements Parcelable{
    /** message text */
    private String mText;
    /** message type */
    private MessageStatus mStatus;

    /** message status enum */
    public enum MessageStatus {
        OK,
        WARNING,
        ERROR
    }

    /** basic constructor
     * @param text message text
     * @param status message type
     */
    public StatusInfo(String text, MessageStatus status) {
        mText = text;
        mStatus = status;
    }

    /** parcel creator */
    public static final Parcelable.Creator CREATOR =
            new Parcelable.Creator() {
                @Override
                public StxErrorMessage createFromParcel(Parcel in) {
                    return new StxErrorMessage(in);
                }

                @Override
                public StxErrorMessage[] newArray(int size) {
                    return new StxErrorMessage[size];
                }
            };

    /** TODO dummy method */
    @Override
    public int describeContents() {
        return 0;
    }

    /** method that converts StatusInfo to Parcel
     * @param out output Parcel
     * @param flags flags
     */
    @Override
    public void writeToParcel(Parcel out, int flags) {
        out.writeInt(mStatus.ordinal());
        out.writeString(mText);
    }

    /** constructor that converts Parcel to StatusInfo
     * @param in input Parcel
     */
    public StatusInfo(Parcel in) {
        int enumItem = in.readInt();
        switch(enumItem) {
            case 0: mStatus = MessageStatus.OK;
                break;
            case 1: mStatus = MessageStatus.WARNING;
                break;
            case 2: mStatus = MessageStatus.ERROR;
        }
        mText = in.readString();
    }

    public String GetText() { return mText;}
    public void SetText(String text) { mText = text;}
    public MessageStatus GetStatus() { return mStatus;}
    public void SetStatus(MessageStatus status) { mStatus = status;}
}
